Package: dataseries
Type: Package
Title: Switzerland's Data Series in One Place
Version: 0.2.0
Date: 2017-04-29
Author: Christoph Sax
Maintainer: Christoph Sax <christoph.sax@gmail.com>
Description: Download and import time series from <http://www.dataseries.org>, a comprehensive and up-to-date collection of open data from Switzerland.
Suggests: xts
License: GPL-3
URL: http://www.dataseries.org
BugReports: https://github.com/christophsax/dataseries
RoxygenNote: 6.0.1
NeedsCompilation: no
Packaged: 2017-04-29 07:07:34 UTC; christoph
Repository: CRAN
Date/Publication: 2017-04-29 12:57:56 UTC
Built: R 4.6.0; ; 2026-04-25 10:42:19 UTC; unix
