% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/catalog.R
\name{ds_catalog}
\alias{ds_catalog}
\title{Catalog of available datasets}
\usage{
ds_catalog()
}
\value{
A \code{data.frame} with one row per dataset and the columns \code{id},
\code{title}, \code{concept}, \code{topic}, \code{source}, \code{license}, \code{frequency}, \code{start},
\code{end} and \code{n_series}.
}
\description{
Lists every dataset available on \href{https://dataseries.org}{dataseries.org},
one row per dataset. Use the \code{id} column with \code{\link[=ds]{ds()}} to download data and
with \code{\link[=ds_meta]{ds_meta()}} to inspect a dataset's dimensions.
}
\examples{
\dontrun{
cat <- ds_catalog()
head(cat)

# search the catalog
cat[grepl("price", cat$title, ignore.case = TRUE), c("id", "title")]
}
}
